@@ -13,21 +13,25 @@ from torch.utils.data import RandomSampler, SequentialSampler
 
 import zcls.util.distributed as du
 
+from ..datasets.mp_dataset import MPDataset
+
 
 def build_sampler(cfg, dataset):
     world_size = du.get_world_size()
     num_gpus = cfg.NUM_GPUS
     rank = du.get_rank()
-    if num_gpus > 1:
+
+    if num_gpus <= 1:
+        if cfg.DATALOADER.RANDOM_SAMPLE:
+            sampler = RandomSampler(dataset)
+        else:
+            sampler = SequentialSampler(dataset)
+    else:
         shuffle = cfg.DATALOADER.RANDOM_SAMPLE
         sampler = DistributedSampler(dataset,
                                      num_replicas=world_size,
                                      rank=rank,
                                      shuffle=shuffle)
-    elif cfg.DATALOADER.RANDOM_SAMPLE:
-        sampler = RandomSampler(dataset)
-    else:
-        sampler = SequentialSampler(dataset)
 
     return sampler
 
@@ -35,12 +39,12 @@ def build_sampler(cfg, dataset):
 def build_dataloader(cfg, dataset, is_train=True):
     batch_size = cfg.DATALOADER.TRAIN_BATCH_SIZE if is_train else cfg.DATALOADER.TEST_BATCH_SIZE
 
-    sampler = build_sampler(cfg, dataset)
+    sampler = None if isinstance(dataset, MPDataset) else build_sampler(cfg, dataset)
     data_loader = DataLoader(dataset,
                              num_workers=cfg.DATALOADER.NUM_WORKERS,
                              sampler=sampler,
                              batch_size=batch_size,
-                             drop_last=False,
+                             drop_last=is_train,
                              # [When to set pin_memory to true?](https://discuss.pytorch.org/t/when-to-set-pin-memory-to-true/19723)
                              pin_memory=True)
 
